@@ -181,7 +181,7 @@ class Catalog(Service):
                                        list is a 4-tuple of rgba values
                                        to map pixels whose value is the
                                        index of the tuple. e.g. the
-                                       colormap [["100", "20", "200", "255"]]
+                                       colormap [[100, 20, 200, 255]]
                                        would map pixels whose value is 0 in
                                        the original band, to the rgba color
                                        vector at colormap[0].  Less than
@@ -754,7 +754,7 @@ class Catalog(Service):
                                                list is a 4-tuple of rgba values
                                                to map pixels whose value is the
                                                index of the tuple. e.g. the colormap
-                                               [["100", "20", "200", "255"]] would
+                                               [[100, 20, 200, 255]] would
                                                map pixels whose value is 0 in the
                                                original band, to the rgba color
                                                vector at colormap[0].  Less than
@@ -917,7 +917,7 @@ class Catalog(Service):
                                   ['plasma', 'magma', 'viridis', 'msw', 'inferno']
         :param list(list(str)) colormap: A custom colormap to use for this band. Takes a list of lists, where each
                                          nested list is a 4-tuple of rgba values to map pixels whose value is the index
-                                         of the tuple. e.g. the colormap [["100", "20", "200", "255"]] would map pixels
+                                         of the tuple. e.g. the colormap [[100, 20, 200, 255]] would map pixels
                                          whose value is 0 in the original band, to the rgba color vector at colormap[0].
                                          Less than 2^nbits 4-tuples may be provided, and omitted values
                                          will default map to black.
@@ -1263,7 +1263,7 @@ class Catalog(Service):
             fields bucket, directory, files, file_md5s, file_sizes. Default is `"available"`.
         :param list(str) writers: A list of groups, or user hashes to give read access to.
         :param dict extra_properties: User defined custom properties for this image.
-            Only 10 keys are allowed. The dict can only map strings to primitive types (str -> str|float|int).
+            Up to 50 keys are allowed. The dict can only map strings to primitive types (str -> str|float|int).
 
         :rtype: dict
         :return: JSON API representation of the band. See :meth:`get_image`
@@ -1455,7 +1455,11 @@ class Catalog(Service):
                 )
         else:
             failed, upload_id, error = self._do_upload(
-                files, product_id, image_id, metadata=metadata, add_namespace=add_namespace
+                files,
+                product_id,
+                image_id,
+                metadata=metadata,
+                add_namespace=add_namespace,
             )
 
         if failed:
@@ -1770,7 +1774,9 @@ class Catalog(Service):
 
         return failed, upload_id, error
 
-    def _do_upload(self, file_ish, product_id, image_id=None, metadata=None, add_namespace=False):
+    def _do_upload(
+        self, file_ish, product_id, image_id=None, metadata=None, add_namespace=False
+    ):
         # kwargs are treated as metadata fields and restricted to primitives
         # for the key val pairs.
         fd = None
@@ -1808,7 +1814,9 @@ class Catalog(Service):
             return True, upload_id, e
 
         try:
-            upload_id = image_id or metadata.pop("image_id", None) or os.path.basename(fd.name)
+            upload_id = (
+                image_id or metadata.pop("image_id", None) or os.path.basename(fd.name)
+            )
 
             r = self.session.post(
                 "/products/{}/images/upload/{}".format(product_id, upload_id),
