@@ -32,7 +32,10 @@ from warnings import warn
 from tempfile import NamedTemporaryFile
 import zipfile
 
-import cloudpickle
+try:
+    import cloudpickle
+except ImportError:
+    pass
 
 from descarteslabs.client.auth import Auth
 from descarteslabs.client.exceptions import ConflictError
@@ -67,6 +70,12 @@ CREATE_NAMESPACE_DEPRECATION_MESSAGE = (
     "Manually creating a namespace is no longer required."
 )
 
+PICKLE_DEPRECATION_MESSAGE = (
+    "Support for this Task function behavior has been deprecated "
+    "and will be removed in a future version. Please correct the "
+    "following error to ensure forwards compatibility: {}"
+)
+
 
 class GroupTerminalException(Exception):
     pass
@@ -139,7 +148,7 @@ class Tasks(Service):
 
         :return: `True` if successful, `False` otherwise.
         """
-        warn(CREATE_NAMESPACE_DEPRECATION_MESSAGE, DeprecationWarning)
+        warn(CREATE_NAMESPACE_DEPRECATION_MESSAGE, FutureWarning)
         return self._create_namespace()
 
     def new_group(
@@ -233,22 +242,23 @@ class Tasks(Service):
 
         bundle_path = None
         try:
-            if (
-                include_data is not None
-                or include_modules is not None
-                or requirements is not None
-            ):
+            try:
                 bundle_path = self._build_bundle(
                     function, include_data, include_modules, requirements
                 )
                 payload.update({"function_type": FunctionType.PY_BUNDLE})
-            else:
+            except (ValueError, BoundGlobalError) as e:
+                # deprecated support for pickled functions
+                # to be removed in a future release
+                if include_modules or include_data or requirements:
+                    raise
                 payload.update(
                     {
                         "function": _serialize_function(function),
                         "function_type": FunctionType.PY_PICKLE,
                     }
                 )
+                warn(PICKLE_DEPRECATION_MESSAGE.format(e), FutureWarning)
 
             try:
                 r = self.session.post("/groups", json=payload)
@@ -639,7 +649,7 @@ class Tasks(Service):
         :rtype: DotDict
         """
         if offset is not None:
-            warn(OFFSET_DEPRECATION_MESSAGE, DeprecationWarning)
+            warn(OFFSET_DEPRECATION_MESSAGE, FutureWarning)
 
         params = {"limit": limit}
         for field in [
@@ -942,7 +952,7 @@ class Tasks(Service):
             given name exists.
         :rtype: :class:`CloudFunction`
         """
-        warn(GET_FUNCTION_DEPRECATION_MESSAGE, DeprecationWarning)
+        warn(GET_FUNCTION_DEPRECATION_MESSAGE, FutureWarning)
 
         group_info = self.get_group_by_name(name)
         if group_info is None:
@@ -1009,7 +1019,7 @@ class Tasks(Service):
             the supplied parameters are invalid.
         """
 
-        warn(CREATE_OR_GET_DEPRECATION_MESSAGE, DeprecationWarning)
+        warn(CREATE_OR_GET_DEPRECATION_MESSAGE, FutureWarning)
 
         if name:
             cached = self.get_function(name)
@@ -1646,13 +1656,20 @@ def _serialize_function(function):
     # Note; In Py3 cloudpickle and base64 handle bytes objects only, so we need to
     # decode it into a string to be able to json dump it again later.
     cp_version = getattr(cloudpickle, "__version__", None)
-    if cp_version is None or cp_version != "0.4.0":
-        warn(
-            (
-                "You must use version 0.4.0 of cloudpickle for compatibility with the Tasks client. {} found."
-            ).format(cp_version)
-        )
-
+    if sys.version_info < (3, 8, 0):
+        if cp_version is None or cp_version != "0.4.0":
+            warn(
+                (
+                    "You must use version 0.4.0 of cloudpickle for compatibility with the Tasks client. {} found."
+                ).format(cp_version)
+            )
+    else:
+        if cp_version is None or cp_version != "1.6.0":
+            warn(
+                (
+                    "You must use version 1.6.0 of cloudpickle for compatibility with the Tasks client. {} found."
+                ).format(cp_version)
+            )
     encoded_bytes = base64.b64encode(cloudpickle.dumps(function))
     return encoded_bytes.decode("ascii")
 
