@@ -6,6 +6,9 @@ from .client import (
     function_graft,
     merge_value_grafts,
     guid,
+    isolate_keys,
+    parametrize,
+    consistent_guid,
 )
 
 __all__ = [
@@ -16,4 +19,7 @@ __all__ = [
     "function_graft",
     "merge_value_grafts",
     "guid",
+    "isolate_keys",
+    "parametrize",
+    "consistent_guid",
 ]
