@@ -1,4 +1,4 @@
-# Copyright 2018-2019 Descartes Labs.
+# Copyright 2018-2020 Descartes Labs.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -67,7 +67,7 @@ def search(
     limit : int or None, optional, default 100
         Maximum number of Scenes to return, or None for all results.
     sort_field : str, optional
-        Field name in `Scene.properties` by which to order the results
+        Field name in :py:attr:`Scene.properties` by which to order the results
     sort_order : str, optional, default 'asc'
         ``"asc"`` or ``"desc"``
     date_field : str, optional, default 'acquired'
@@ -79,7 +79,8 @@ def search(
         You can construct filter expression using the ``==``, ``!=``, ``<``, ``>``,
         ``<=`` and ``>=`` operators as well as the
         :meth:`~descarteslabs.common.property_filtering.filtering.Property.like`
-        method. You cannot use the boolean keywords ``and`` and ``or`` because of
+        and :meth:`~descarteslabs.common.property_filtering.filtering.Property.in_`
+        methods. You cannot use the boolean keywords ``and`` and ``or`` because of
         Python language limitations; instead you can combine filter expressions
         with ``&`` (boolean "and") and ``|`` (boolean "or").
         Example:
