@@ -1,15 +1,18 @@
-from .exceptions import JobComputeError, TimeoutError
+from .exceptions import JobComputeError, JobTimeoutError
 from .workflow import Workflow
+from .versionedgraft import VersionedGraft
 from .job import Job
 from .xyz import XYZ, XYZErrorListener
-from .toplevel import compute, publish, retrieve, use
+from .toplevel import compute, publish, use
 
 __all__ = [
     # .exceptions
     "JobComputeError",
-    "TimeoutError",
+    "JobTimeoutError",
     # .workflow
     "Workflow",
+    # .versionedgraft
+    "VersionedGraft",
     # .job
     "Job",
     # .xyz
@@ -18,6 +21,5 @@ __all__ = [
     # .toplevel
     "compute",
     "publish",
-    "retrieve",
     "use",
 ]
