@@ -1,11 +1,8 @@
-import sys
 import six
 
 from descarteslabs.common.graft import client, syntax
 from .exceptions import ProxyTypeError
 
-PY36 = sys.version_info[:2] >= (3, 6)
-
 
 class Castable(object):
     "Mixin to support casting without explicitly allowing it in ``__init__``"
@@ -48,7 +45,15 @@ class Proxytype(Castable):
         "Returns `obj` as type `cls`, or raises `ProxyTypeError` if promotion is not possible."
         if isinstance(obj, cls):
             return obj
-        raise ProxyTypeError("Cannot promote {} to {}".format(obj, cls.__name__))
+        try:
+            # Promote Any via casting. To avoid circular imports, we duck-type this
+            # and consider `.cast` to be an interface; if an object has a `.cast` method
+            # we might as well try it.
+            return obj.cast(cls)
+        except Exception:
+            raise ProxyTypeError(
+                "Cannot promote {} to {}".format(obj, cls.__name__)
+            ) from None
 
     def __bool__(self):
         # Ensure Proxytypes can't be used in conditionals;
@@ -59,19 +64,17 @@ class Proxytype(Castable):
             )
         )
 
-    __nonzero__ = __bool__  # for python 2
-
     def __contains__(self, _):
         if hasattr(self, "contains"):
             raise TypeError(
                 (
                     "Please use {}.contains(other). Python requires a bool to be returned "
                     "from __contains__ and this value cannot be known for proxy types."
-                ).format(self.__class__.__name__)
+                ).format(type(self).__name__)
             )
         else:
             raise TypeError(
-                "object of type {} has no contains().".format(self.__class__.__name__)
+                "object of type {} does not support `in`.".format(type(self).__name__)
             )
 
     def __len__(self):
@@ -80,11 +83,23 @@ class Proxytype(Castable):
                 (
                     "Please use {}.length(). Python requires an int to be returned "
                     "from __len__ and this value cannot be known for proxy types."
-                ).format(self.__class__.__name__)
+                ).format(type(self).__name__)
             )
         else:
             raise TypeError(
-                "object of type {} has no length()".format(self.__class__.__name__)
+                "object of type {} has no len()".format(type(self).__name__)
+            )
+
+    def __iter__(self):
+        if hasattr(self, "map"):
+            raise TypeError(
+                (
+                    "Proxy {0} is not iterable. Consider using {0}.map(...) instead."
+                ).format(type(self).__name__)
+            )
+        else:
+            raise TypeError(
+                "object of type {} is not iterable.".format(type(self).__name__)
             )
 
     # NOTE(gabe): if you're looking for the `compute` and `persist` helper methods,
@@ -96,8 +111,7 @@ class Proxytype(Castable):
 class GenericProxytypeMetaclass(type):
     """
     Override ``isinstance`` and ``issubclass`` to make them covariant
-    for `GenericProxytype`s and their concrete subclasses, and support
-    ``__init_subclass__`` in Python < 3.6.
+    for `GenericProxytype`s and their concrete subclasses.
 
     Formally: ``issubclass(typA, typB) is True`` iff the generic type of ``typA``
     is a subclass of the generic type of ``typB``, and all the type parameters of ``typA``
@@ -129,12 +143,8 @@ class GenericProxytypeMetaclass(type):
     This ensure that, for example, ``List[Int]`` is always the same object,
     so comparing ``typA is typB`` is a safe way to determine iff they're exactly the same type.
 
-    Horrifyingly, it also implements ``__getitem__`` to emulate ``__class_getitem__`` in Python 2,
+    Horrifyingly, it also implements ``__getitem__`` to emulate ``__class_getitem__`` in Python < 3.7,
     so ``List[Str]`` works in both versions.
-
-    The backport of ``__init_subclass__`` in Python < 3.6 matches
-    https://docs.python.org/3/reference/datamodel.html#object.__init_subclass__,
-    except that ``__init_subclass__`` must be decorated with ``@classmethod``.
     """
 
     def __instancecheck__(self, obj):
@@ -197,16 +207,8 @@ class GenericProxytypeMetaclass(type):
         cls._concrete_subtypes = {}
         super(GenericProxytypeMetaclass, cls).__init__(name, bases, dct)
 
-        if not PY36:
-            parent_cls = super(cls, cls)
-            if hasattr(parent_cls, "__init_subclass__"):
-                parent_cls.__init_subclass__()
-                # NOTE(gabe): you'd think the `cls` argument passed into the `__init_subclass__`
-                # classmethod would be `parent_cls` here, but it's actualy just `cls`,
-                # so this correctly follows the `__init_subclass__` py3.6 API.
-
     def __getitem__(cls, idx):
-        "Emulate __class_getitem__ for Python 2"
+        "Emulate __class_getitem__ for Python < 3.7"
         try:
             return cls.__class_getitem__(idx)
         except AttributeError:
@@ -220,22 +222,22 @@ def _type_params_issubclass(type_params, super_type_params):
     Recursively descends tuples and dicts in the type params to determine if
     `type_params` covariantly describes a subclass of `super_type_params`.
     """
-    if isinstance(type_params, tuple) and isinstance(super_type_params, tuple):
+    if type(type_params) is not type(super_type_params):
+        return False
+
+    if isinstance(type_params, PRIMITIVES):
+        return type_params == super_type_params
+    elif isinstance(type_params, tuple):
         return len(type_params) == len(super_type_params) and all(
             _type_params_issubclass(cls, super_cls)
             for cls, super_cls in zip(type_params, super_type_params)
         )
-    elif isinstance(type_params, dict) and isinstance(super_type_params, dict):
+    elif isinstance(type_params, dict):
         return six.viewkeys(type_params) == six.viewkeys(super_type_params) and all(
             _type_params_issubclass(cls, super_type_params[key])
             for key, cls in six.iteritems(type_params)
         )
     else:
-        if isinstance(type_params, (tuple, dict)) or isinstance(
-            super_type_params, (tuple, dict)
-        ):
-            # above checks don't catch just 1 param being a tuple or dict
-            return False
         return issubclass(type_params, super_type_params)
 
 
@@ -323,6 +325,10 @@ class GenericProxytype(Proxytype):
     Since `GenericProxytype` uses the `GenericProxytypeMetaclass`, by inheriting from it,
     the Python ``isinstance`` and ``issubclass`` methods will also behave covariantly for your
     custom generic type: ``issubclass(MyType[MyIntSubclass], `MyType[Int])`` will be True.
+
+    By implementing ``_validate_params``, you can customize the valid type parameters of a class.
+    ``_validate_params`` should take a tuple of type parameters and apply appropriate validation
+    to each (in most cases you will at least want to validate that each type parameter is a subclass of Proxytype).
     """
 
     _type_params = None
@@ -336,22 +342,8 @@ class GenericProxytype(Proxytype):
                     cls.__name__
                 )
             )
-        if not isinstance(type_params, tuple):
-            type_params = (type_params,)
-        for i, type_param in enumerate(type_params):
-            if isinstance(type_param, dict):
-                assert all(
-                    issubclass(param_cls, Proxytype)
-                    for param_cls in six.itervalues(type_param)
-                ), "Values in type parameter dict must all be Proxytypes: parameter {}: {}".format(
-                    i, type_param
-                )
-            else:
-                assert issubclass(
-                    type_param, Proxytype
-                ), "Type parameters must be Proxytypes, but for parameter {}, got {}".format(
-                    i, type_param
-                )
+
+        type_params = validate_typespec(type_params)
 
         # Look up these parameters in the _concrete_subtypes registry. If we've already created a
         # type for these parameters, return that object instead of making a duplicate.
@@ -366,6 +358,9 @@ class GenericProxytype(Proxytype):
         try:
             return cls._concrete_subtypes[hashable_type_params]
         except KeyError:
+            if hasattr(cls, "_validate_params"):
+                cls._validate_params(type_params)
+
             param_names = (
                 # Default dict formatting would print values like `<class 'descarteslabs.common.proxytypes.Int'>`,
                 # so we do our own dict formatting using `cls.__name__` for read/copy-ability
@@ -377,6 +372,8 @@ class GenericProxytype(Proxytype):
                 )
                 if isinstance(type_param, dict)
                 else type_param.__name__
+                if isinstance(type_param, type)
+                else str(type_param)
                 for type_param in type_params
             )
 
@@ -409,8 +406,30 @@ class GenericProxytype(Proxytype):
     def _promote(cls, obj):
         if isinstance(obj, cls):
             return obj
+        try:
+            # Promote Any via casting. To avoid circular imports, we duck-type this
+            # and consider `.cast` to be an interface; if an object has a `.cast` method
+            # we might as well try it.
+            return obj.cast(cls)
+        except Exception:
+            pass
         return cls(obj)
 
+    @classmethod
+    def _from_graft(cls, graft):
+        """
+        Create an instance of this class with the given graft dict, circumventing ``__init__``
+
+        To use safely, this class must function correctly if its ``__init__`` method is not called.
+
+        This is used to let your class present a friendly user-facing constructor,
+        but still support copy-constuction or casting when necessary.
+        """
+        assert not is_generic(cls), "Cannot instantiate a generic {}".format(
+            cls.__name__
+        )
+        return super(GenericProxytype, cls)._from_graft(graft)
+
 
 def is_generic(type_):
     """
@@ -422,4 +441,52 @@ def is_generic(type_):
     if type_parameters is not None:
         return any(map(is_generic, type_parameters))
 
+    if isinstance(type_, dict):
+        # in this case `type_` is a 'complex type', `dict[Type:Type]`
+        complex_type = type_
+        return any(map(is_generic, complex_type.keys())) and any(
+            map(is_generic, complex_type.values())
+        )
+
+    if isinstance(type_, PRIMITIVES):
+        return False
     return issubclass(type_, GenericProxytype)
+
+
+PRIMITIVES = (int, float, bool, str)
+
+
+def validate_typespec(type_params):
+    "Ensures that type parameters are of a valid form (Proxytype, Python primitive, tuples or dicts of these)"
+    if not isinstance(type_params, tuple):
+        type_params = (type_params,)
+    for i, type_param in enumerate(type_params):
+        if isinstance(type_param, dict):
+            for key, param_cls in six.iteritems(type_param):
+                validate_typespec(key)
+                validate_typespec(param_cls)
+        elif isinstance(type_param, PRIMITIVES):
+            pass
+        else:
+            # we try-except here so we can throw a better
+            # error when type_param is a Proxytype instance
+            # rather than the issubclass error
+            try:
+                assert issubclass(type_param, Proxytype)
+            except (TypeError, AssertionError):
+                raise TypeError(
+                    "Type parameters must be Proxytypes, Python primitive values, "
+                    "or tuples or dicts of those, but got {!r}".format(type_param)
+                )
+    return type_params
+
+
+def assert_is_proxytype(type_, error_message=None):
+    try:
+        assert issubclass(type_, Proxytype)
+    except (AssertionError, TypeError):
+        if error_message is None:
+            error_message = "Expected a Proxytype type object, but got {!r}".format(
+                type_
+            )
+        raise TypeError(error_message) from None
